use eframe::egui;
use state::AppState;

pub mod model_response;
pub mod model_selection;
pub mod prompt_input;
pub mod state;

pub fn main() -> eframe::Result {
    let options = eframe::NativeOptions {
        viewport: eframe::egui::ViewportBuilder::default().with_inner_size([900.0, 600.0]),
        ..Default::default()
    };

    eframe::run_native(
        "Groq Model Comparison",
        options,
        Box::new(|cc| Ok(Box::new(AppState::new(cc)))),
    )
}

impl eframe::App for AppState {
    fn update(&mut self, ctx: &egui::Context, _frame: &mut eframe::Frame) {
        egui::CentralPanel::default().show(ctx, |ui| {
            ui.heading("Groq Model Comparison");
            ui.label("Compare Groq models with ease!");

            ui.add(model_selection::ModelSelection::new(
                self,
                vec!["Model 1".to_string(), "Model 2".to_string()],
            ));

            ui.add(prompt_input::PromptInput::new(self));

            ui.horizontal(|ui| {
                for model in &self.selected_models {
                    ui.vertical(|ui| ui.add(model));
                }
            });
        });
    }
}
